@@ -2,7 +2,9 @@
 
 #include "hercules-store.hh"
 #include "hercules-logger.hh"
-#include "derivations.hh"
+#include <hercules-ci-cnix/store.hxx>
+#include <hercules-ci-cnix/expr.hxx>
+#include <nix/store/derivations.hh>
 
 // inline-c-cpp doesn't seem to handle namespace operator or template
 // syntax so we help it a bit for now. This definition can be inlined
@@ -18,7 +20,6 @@ typedef std::queue<std::unique_ptr<HerculesLogger::LogEntry>> LogEntryQueue;
 
 typedef nix::Strings::iterator StringsIterator;
 typedef nix::DerivationOutputs::iterator DerivationOutputsIterator;
-typedef nix::DerivationInputs::iterator DerivationInputsIterator;
 typedef nix::StringPairs::iterator StringPairsIterator;
 
 using namespace std;
\ No newline at end of file
