@@ -1,15 +1,15 @@
 module Data.Map.Extras.Hercules where
 
 import Control.Arrow ((&&&))
-import qualified Data.List as L
-import qualified Data.List.NonEmpty as NEL
-import qualified Data.Map as M
+import Data.List qualified as L
+import Data.List.NonEmpty qualified as NEL
+import Data.Map qualified as M
 import Protolude hiding (groupBy)
 
-groupOn :: Ord k => (a -> k) -> [a] -> M.Map k [a]
+groupOn :: (Ord k) => (a -> k) -> [a] -> M.Map k [a]
 groupOn f = fmap toList . groupOnNEL f
 
-groupOnNEL :: Ord k => (a -> k) -> [a] -> M.Map k (NEL.NonEmpty a)
+groupOnNEL :: (Ord k) => (a -> k) -> [a] -> M.Map k (NEL.NonEmpty a)
 groupOnNEL f =
   M.fromList
     . map (fst . NEL.head &&& map snd)
