@@ -1,3 +1,4 @@
+{-# LANGUAGE DerivingStrategies #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
 
 module Hercules.Agent.Bag
@@ -9,19 +10,19 @@ module Hercules.Agent.Bag
 where
 
 import Data.Aeson
+import Data.Aeson.KeyMap qualified as AK
 import Data.Aeson.Types
 import Data.Functor.Compose
 import Data.Functor.Partitioner hiding
   ( part,
   )
-import qualified Data.HashMap.Strict as HashMap
 import Protolude
 
 -- TODO: Use a Validation instead of Either to return all errors at once
 
 -- | Partitioning and validation for heterogeneous JSON maps
 newtype ParseBag a b = ParseBag {getReadBag :: Compose (Partitioner (WithKey Text a)) Parser b}
-  deriving (Functor, Applicative)
+  deriving newtype (Functor, Applicative)
 
 -- | Text argument: Map key, a: thing you're parsing. Return 'Nothing' to skip the object and let another part handle it.
 part :: (Text -> a -> Maybe (Parser b)) -> ParseBag a (Map Text b)
@@ -37,7 +38,7 @@ parseBag f v = do
 whenKind :: Text -> (Value -> Maybe a) -> Value -> Maybe a
 whenKind expectedKind f v@(Object o) =
   ( do
-      x <- HashMap.lookup "kind" o
+      x <- AK.lookup "kind" o
       guard (x == String expectedKind)
   )
     *> f v
