@@ -1,6 +1,6 @@
 module Hercules.Agent.Cachix.Info where
 
-import qualified Data.Map as M
+import Data.Map qualified as M
 import Hercules.Agent.Cachix.Env
 import Protolude
 
