@@ -8,17 +8,17 @@ where
 import Hercules.Agent.CabalInfo (herculesAgentVersion)
 import Hercules.Agent.Config (ConfigPath (..))
 import Options.Applicative
-import Protolude hiding (option)
+import Protolude
 
-data Options
-  = Options
-      { configFile :: ConfigPath,
-        mode :: Mode
-      }
+data Options = Options
+  { configFile :: ConfigPath,
+    mode :: Mode
+  }
 
 parseOptions :: Parser Options
 parseOptions =
-  Options <$> parseConfigPath
+  Options
+    <$> parseConfigPath
     <*> parseMode
 
 data Mode = Test | Run
@@ -31,18 +31,20 @@ parseMode =
 
 parseConfigPath :: Parser ConfigPath
 parseConfigPath =
-  TomlPath
+  ConfigPath
     <$> strOption
-      ( long "config" <> metavar "FILE"
+      ( long "config"
+          <> metavar "FILE"
           <> help
-            "File path to the configuration file (TOML)"
+            "File path to the configuration file (TOML, or JSON if the path ends in .json)"
       )
 
 parserInfo :: ParserInfo Options
 parserInfo =
   info
     (parseOptions <**> helper)
-    ( fullDesc <> progDesc "Accepts tasks from Hercules CI and runs them."
+    ( fullDesc
+        <> progDesc "Accepts tasks from Hercules CI and runs them."
         <> header
           ("hercules-ci-agent " <> toS herculesAgentVersion)
     )
