@@ -12,25 +12,25 @@ module Hercules.Agent.STM
 where
 
 import Control.Concurrent.STM (STM, TBQueue, TChan, TVar, readTVar, writeTVar)
-import qualified Control.Concurrent.STM as STM
+import Control.Concurrent.STM qualified as STM
 import Protolude hiding (atomically)
 
-atomically :: MonadIO m => STM a -> m a
+atomically :: (MonadIO m) => STM a -> m a
 atomically = liftIO . STM.atomically
 
-readTVarIO :: MonadIO m => TVar a -> m a
+readTVarIO :: (MonadIO m) => TVar a -> m a
 readTVarIO = liftIO . STM.readTVarIO
 
-newTVarIO :: MonadIO m => a -> m (TVar a)
+newTVarIO :: (MonadIO m) => a -> m (TVar a)
 newTVarIO = liftIO . STM.newTVarIO
 
 -- | Drop-in replacement for atomicModifyIORef
-modifyTVarIO :: MonadIO m => TVar a -> (a -> (a, b)) -> m b
+modifyTVarIO :: (MonadIO m) => TVar a -> (a -> (a, b)) -> m b
 modifyTVarIO tvar f = atomically $ do
   a0 <- readTVar tvar
   let (a1, b) = f a0
   writeTVar tvar a1
   pure b
 
-newTChanIO :: MonadIO m => m (TChan a)
+newTChanIO :: (MonadIO m) => m (TChan a)
 newTChanIO = liftIO STM.newTChanIO
