@@ -6,10 +6,17 @@ import Data.Binary
 import Protolude
 import Prelude ()
 
-data Attribute
-  = Attribute
-      { path :: [ByteString],
-        drv :: ByteString
-        -- TODO: metadata
-      }
+data AttributeType
+  = Regular
+  | MustFail
+  | MayFail
+  | DependenciesOnly
+  | Effect
+  deriving (Generic, Binary, Show, Eq)
+
+data Attribute = Attribute
+  { path :: [ByteString],
+    drv :: ByteString,
+    typ :: AttributeType
+  }
   deriving (Generic, Binary, Show, Eq)
