@@ -6,11 +6,11 @@ import Data.Binary
 import Protolude
 import Prelude ()
 
-data AttributeError
-  = AttributeError
-      { path :: [ByteString],
-        message :: Text,
-        errorType :: Maybe Text,
-        errorDerivation :: Maybe Text
-      }
+data AttributeError = AttributeError
+  { path :: [ByteString],
+    message :: Text,
+    errorType :: Maybe Text,
+    errorDerivation :: Maybe Text,
+    trace :: Maybe Text
+  }
   deriving (Generic, Binary, Show, Eq)
