@@ -1,6 +1,6 @@
 module Hercules.Agent.WorkerProcessSpec (spec) where
 
-import qualified Data.Map as M
+import Data.Map qualified as M
 import Hercules.API.Agent.Evaluate.EvaluateTask
 import Hercules.Agent.WorkerProcess
 import Protolude
@@ -9,10 +9,10 @@ import Test.Hspec
 spec :: Spec
 spec = do
   describe "modifyEnv" $ do
-    let baseEnvSettings = WorkerEnvSettings []
+    let baseEnvSettings = WorkerEnvSettings [] mempty
         baseEnv = M.fromList [("NIX_PATH", "")]
     it "sets NIX_PATH" $ \() -> do
-      modifyEnv (WorkerEnvSettings [NixPathElement (Just "a") $ SubPathOf "/b" Nothing]) mempty
+      modifyEnv (WorkerEnvSettings [NixPathElement (Just "a") $ SubPathOf "/b" Nothing] mempty) mempty
         `shouldBe` M.fromList [("NIX_PATH", "a=/b")]
     it "filters out NIXPKGS_CONFIG" $ do
       modifyEnv baseEnvSettings ("NIXPKGS_CONFIG" =: "abpuhasur")
